#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "QDebug"
#include<Windows.h>

#include"CyAPI.h"

#include<qdebug.h>

#define USB30 0x0300


MainWindow::MainWindow(QWidget *parent)
    : QMainWindow(parent)
    , ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    pUSB = new CCyUSBDevice(this, CYUSBDRV_GUID, true);//创建USB设备对象

}

MainWindow::~MainWindow()
{
    delete ui;
}



//搜寻存在的USB设置并添加到列表中
BOOL MainWindow::SurveyExistingDevices()
{
    CCyUSBDevice	*USBDevice;
    USBDevice = new CCyUSBDevice(this, CYUSBDRV_GUID, true);

    QString strDevice;
    int nCboIndex = -1;

    ui->comboBoxDev->clear();

    if (USBDevice != NULL)
    {
        int nDeviceCount = USBDevice->DeviceCount();
        for (int nCount = 0; nCount < nDeviceCount; nCount++)
        {
            QString strDeviceData;
            USBDevice->Open(nCount);

            strDeviceData = QString("(0x%1%2 - 0x%3%4) %5").arg(
                        QString::number(USBDevice->VendorID >> 8 , 16),
                        QString::number(USBDevice->VendorID & 0xff , 16),
                        QString::number(USBDevice->ProductID >> 8 , 16),
                        QString::number(USBDevice->ProductID & 0xff , 16),
                        QString::fromLocal8Bit(USBDevice->FriendlyName,256)
                        );

            if (USBDevice->bHighSpeed)
                strDeviceData += " (HighSpeed)";
            else if (USBDevice->bSuperSpeed)
                strDeviceData += " (SuperSpeed)";

            ui->comboBoxDev->addItem(strDeviceData);
            if (nCboIndex == -1 && strDevice.isEmpty() == FALSE && strDevice == strDeviceData)
                nCboIndex = nCount;

            USBDevice->Close();
        }
        delete USBDevice;
        if (ui->comboBoxDev->count() >= 1)
        {
            if (nCboIndex != -1)
                ui->comboBoxDev->setCurrentIndex(nCboIndex);
            else
                ui->comboBoxDev->setCurrentIndex(0);
        }
        else
        {

        }
    }
    else
    {
        return FALSE;
    }

    return TRUE;
}

//为设备初始化端点信息
BOOL MainWindow::EnumerateEndpointForTheSelectedDevice()
{

    // 检查系统是否连接有FX系列的设备
    if(ui->comboBoxDev->count() <= 0)
        return FALSE;

    ui->comboBoxEptOut->clear();
    ui->comboBoxEptIn->clear();

    //如果有连接有效设备，打开设备
    pUSB->Open(ui->comboBoxDev->currentIndex());

    //查看连接了多少个设备
    int interfaces = pUSB->AltIntfcCount() + 1;

    //复位输入和输出端点选择框

    //遍历所有设备，初始化其端点信息
    for (int nDeviceInterfaces = 0; nDeviceInterfaces < interfaces; nDeviceInterfaces++)
    {
        pUSB->SetAltIntfc(nDeviceInterfaces);

        int eptCnt = pUSB->EndPointCount();	//检查该设备有多少个端点

        //读取端点信息
        for (int endPoint = 0; endPoint < eptCnt; endPoint++)
        {
            CCyUSBEndPoint *ept = pUSB->EndPoints[endPoint];

            // INTR, BULK and ISO endpoints are supported.
            if (ept->Attributes == 2)
            {
                QString strData, strTemp;

                strData += ((ept->Attributes == 1) ? "ISOC " : ((ept->Attributes == 2) ? "BULK " : "INTR "));
                strData += (ept->bIn ? "IN, " : "OUT, ");

                strTemp = QString("%1  Bytes,").arg(QString::number(ept->MaxPktSize));
                strData += strTemp;

                if (pUSB->BcdUSB == USB30)
                {
                    strTemp = QString("%1  MaxBurst,").arg(QString::number(ept->ssmaxburst));
                    strData += strTemp;
                }

                strTemp = QString("AltInt - %1 and EpAddr - 0x%2").arg(
                            QString::number(nDeviceInterfaces),
                            QString::number(ept->Address,16));
                strData += strTemp;
                if (ept->bIn)
                {
                    qDebug() << "pt->bIn:" << strData;
                    ui->comboBoxEptIn->addItem(strData);
                }
                else
                {
                    qDebug() << "pt->bOut:" << strData;
                    ui->comboBoxEptOut->addItem(strData);
                }
            }
        }
    }
    return TRUE;
}


void MainWindow::on_pushButtonFindDev_clicked()
{
    SurveyExistingDevices();//搜寻存在的USB设备并添加到列表
    EnumerateEndpointForTheSelectedDevice();//为设备初始化端点信息
}
